import { createContext, useContext, useState } from "react";
import * as api from "../lib/api";
import { toast } from "react-toastify";
export const AppContext = createContext();
export const useAppContext = () => useContext(AppContext);

export function ContextProvider({ children }) {
  const [userseats, setUserSeats] = useState([]);
  const [isLoggedIn, setIsLoggedIn] = useState(false);
  const LoginOrRegister = async ({ mobile }) => {
    try {
      const response = await api.LoginOrRegister({ mobile });
      setIsLoggedIn(true);
      return response;
    } catch (err) {
      toast.error(err.message);
    }
  };
  const AddOrUpdateSeats = async ({ userId, seats }) => {
    try {
      const response = await api.AddOrUpdateSeats({
        userId,
        seats,
      });
      if (response.isAddSeat) {
        setUserSeats([...userseats, response.response]);
      } else {
        const result = userseats.map((e) =>
          e.userId === userId ? response.response : e
        );
        setUserSeats(result);
      }
    } catch (err) {
      toast.error(err.message);
    }
  };
  const GetAllReservedSeats = async () => {
    try {
      const response = await api.GetAllSeats();
      setUserSeats(response);
    } catch (err) {
      toast.error(err.message);
    }
  };
  const value = {
    userseats,
    isLoggedIn,
    LoginOrRegister,
    AddOrUpdateSeats,
    GetAllReservedSeats,
  };
  return <AppContext.Provider value={value}>{children}</AppContext.Provider>;
}
